==> redata-0.4.0.tar.gz: redata-0.4.0/CHANGELOG.md <==
# Changelog

## [v0.4.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.4.0) (2021-05-17)

**Implemented enhancements:**
 - Add issue_requests function to code [#15](http://github.com/UAL-ODIS/redata-commons/pull/15)

**Closed issues:**
 - Add issue_requests function to code [#11](http://github.com/UAL-ODIS/redata-commons/issues/11)


## [v0.3.2](https://github.com/UAL-ODIS/redata-commons/tree/v0.3.2) (2021-04-20)

**Fixed bugs:**
 - Bug: LogCommons has hardcoded pieces [#13](http://github.com/UAL-ODIS/redata-commons/issues/13)

**Merged pull requests:**
 - Bug: LogCommons has hardcoded pieces [#14](http://github.com/UAL-ODIS/redata-commons/pull/14)


## [v0.3.1](https://github.com/UAL-ODIS/redata-commons/tree/v0.3.1) (2021-04-14)

**Implemented enhancements:**
 - Update README.md for Sphinx documentation [#12](http://github.com/UAL-ODIS/redata-commons/pull/12)

**Closed issues:**
 - Update README.md for Sphinx documentation [#9](http://github.com/UAL-ODIS/redata-commons/issues/9)


## [v0.3.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.3.0) (2021-04-05)

**Implemented enhancements:**
 - Add logger module [#10](http://github.com/UAL-ODIS/redata-commons/pull/10)

**Closed issues:**
 - Add logger module [#1](http://github.com/UAL-ODIS/redata-commons/issues/1)


## [v0.2.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.2.0) (2021-03-29)

**Implemented enhancements:**
 - Add sphinx documentation and publish to ReadTheDocs [#8](http://github.com/UAL-ODIS/redata-commons/pull/8)

**Closed issues:**
 - Add sphinx documentation and publish to ReadTheDocs [#5](http://github.com/UAL-ODIS/redata-commons/issues/5)
 - Renaming the repository from redata_commons -> redata-commons [#7](http://github.com/UAL-ODIS/redata-commons/issues/7)


## [v0.1.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.1.0) (2021-03-17)

**Implemented enhancements:**
 - Add `git_info` module, include create release GitHub Actions; Include PyPI
   publishing GitHub Actions [#4](github.com/UAL-ODIS/redata-commons/pull/4)

**Closed issues:**
 - Add `git_info` module [#2](http://github.com/UAL-ODIS/redata-commons/issues/2)
 - Add create release GitHub Actions [#3](http://github.com/UAL-ODIS/redata-commons/issues/3)
 - Include GitHub Actions for automated PyPI publishing [#6](http://github.com/UAL-ODIS/redata-commons/issues/2)
   
<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/UAL-ODIS/redata-commons/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/pull/XX)

**Fixed bugs:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/issues/XX)

**Closed issues:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/issues/XX)

**Merged pull requests:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/pull/XX)

-->

==> redata-0.4.1.tar.gz: redata-0.4.1/CHANGELOG.md <==
# Changelog

## [v0.4.1](https://github.com/UAL-ODIS/redata-commons/tree/v0.4.1) (2021-06-08)

**Implemented enhancements:**
 - redata_request should also provide the requests.Request response [#19](http://github.com/UAL-ODIS/redata-commons/pull/19)

**Closed issues:**
 - redata_request should also provide the requests.Request response [#18](http://github.com/UAL-ODIS/redata-commons/issues/18)


## [v0.4.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.4.0) (2021-05-17)

**Implemented enhancements:**
 - Add issue_requests function to code [#15](http://github.com/UAL-ODIS/redata-commons/pull/15)

**Closed issues:**
 - Add issue_requests function to code [#11](http://github.com/UAL-ODIS/redata-commons/issues/11)


## [v0.3.2](https://github.com/UAL-ODIS/redata-commons/tree/v0.3.2) (2021-04-20)

**Fixed bugs:**
 - Bug: LogCommons has hardcoded pieces [#13](http://github.com/UAL-ODIS/redata-commons/issues/13)

**Merged pull requests:**
 - Bug: LogCommons has hardcoded pieces [#14](http://github.com/UAL-ODIS/redata-commons/pull/14)


## [v0.3.1](https://github.com/UAL-ODIS/redata-commons/tree/v0.3.1) (2021-04-14)

**Implemented enhancements:**
 - Update README.md for Sphinx documentation [#12](http://github.com/UAL-ODIS/redata-commons/pull/12)

**Closed issues:**
 - Update README.md for Sphinx documentation [#9](http://github.com/UAL-ODIS/redata-commons/issues/9)


## [v0.3.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.3.0) (2021-04-05)

**Implemented enhancements:**
 - Add logger module [#10](http://github.com/UAL-ODIS/redata-commons/pull/10)

**Closed issues:**
 - Add logger module [#1](http://github.com/UAL-ODIS/redata-commons/issues/1)


## [v0.2.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.2.0) (2021-03-29)

**Implemented enhancements:**
 - Add sphinx documentation and publish to ReadTheDocs [#8](http://github.com/UAL-ODIS/redata-commons/pull/8)

**Closed issues:**
 - Add sphinx documentation and publish to ReadTheDocs [#5](http://github.com/UAL-ODIS/redata-commons/issues/5)
 - Renaming the repository from redata_commons -> redata-commons [#7](http://github.com/UAL-ODIS/redata-commons/issues/7)


## [v0.1.0](https://github.com/UAL-ODIS/redata-commons/tree/v0.1.0) (2021-03-17)

**Implemented enhancements:**
 - Add `git_info` module, include create release GitHub Actions; Include PyPI
   publishing GitHub Actions [#4](github.com/UAL-ODIS/redata-commons/pull/4)

**Closed issues:**
 - Add `git_info` module [#2](http://github.com/UAL-ODIS/redata-commons/issues/2)
 - Add create release GitHub Actions [#3](http://github.com/UAL-ODIS/redata-commons/issues/3)
 - Include GitHub Actions for automated PyPI publishing [#6](http://github.com/UAL-ODIS/redata-commons/issues/2)
   
<!-- TEMPLATE
## [vXX.YY.ZZ](https://github.com/UAL-ODIS/redata-commons/tree/vXX.YY.ZZ) (YYYY-MM-DD)

**Implemented enhancements:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/pull/XX)

**Fixed bugs:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/issues/XX)

**Closed issues:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/issues/XX)

**Merged pull requests:**
 - `______` [#XX](http://github.com/UAL-ODIS/redata-commons/pull/XX)

-->
